@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,12 +21,10 @@
 #include <QDialog>
 
 class KLineEdit;
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class PlainTextEditorWidget;
 }
-namespace PimCommon
-{
+namespace PimCommon {
 class TemplateEditDialog : public QDialog
 {
     Q_OBJECT
@@ -40,15 +38,13 @@ public:
     void setScript(const QString &);
     QString script() const;
 
-private Q_SLOTS:
-    void slotTemplateChanged();
-
 private:
+    void slotTemplateChanged();
     void readConfig();
     void writeConfig();
-    KPIMTextEdit::PlainTextEditorWidget *mTextEdit;
-    KLineEdit *mTemplateNameEdit;
-    QPushButton *mOkButton;
+    KPIMTextEdit::PlainTextEditorWidget *mTextEdit = nullptr;
+    KLineEdit *mTemplateNameEdit = nullptr;
+    QPushButton *mOkButton = nullptr;
 };
 }
 
